@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 # PYTHON_ARGCOMPLETE_OK
+
 import os
 import shutil
 import json
@@ -7,14 +8,9 @@ import sys
 import errno
 import argparse
 import argcomplete
-from pathlib import Path 
 import IPython
+from pathlib import Path 
 
-from os.path import dirname, abspath
-d = dirname(abspath(__file__))
-
-sys.path.append(d)
-#file=os.path.expanduser("~/.copy_to_confs.json")
 file=os.path.expanduser("~/.config/copy_to/confs.json")
 complete=os.path.expanduser("~/.config/copy_to/")
 folder=os.path.expanduser("~/.config/copy_to/")
@@ -34,7 +30,6 @@ with open(file, 'w') as outfile:
         envs['group'] = [] 
     json.dump(envs, outfile)
 
-
 def is_valid_dir(parser, arg):
     if os.path.isdir(arg):
         return os.path.abspath(arg)
@@ -92,7 +87,7 @@ def PathCompleter(**kwargs):
 def PathOnlyDirsCompleter(**kwargs):
     return [ name for name in os.listdir(str(os.getcwd())) if os.path.isdir(os.path.join(os.getcwd()), name) ]
 
-def SourceComplete():
+def SourceComplete():    
     return range(1,4)
 
 def exist_name(parser, x):
@@ -177,7 +172,14 @@ def get_main_parser():
     argcomplete.autocomplete(parser)
     return parser
 
-if __name__ == "__main__":
+def main():
+
+    """from os.path import dirname, abspath
+    d = dirname(abspath(__file__))
+
+    sys.path.append(d)"""
+    #file=os.path.expanduser("~/.copy_to_confs.json")
+
     parser = get_main_parser()
     args = parser.parse_args()
 
@@ -436,7 +438,7 @@ if __name__ == "__main__":
         parser.print_help()
     else: 
         if args.command == 'list' and "name" in args and args.name:
-            if args.name == ['all']:
+            if args.name == 'all':
                 listAll()
             else:
                 for key, value in envs.items():
@@ -451,3 +453,5 @@ if __name__ == "__main__":
         else:
             pass
 
+if __name__ == "__main__":
+    main()
